/*
 * Copyright 2012 Martin Skurla
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.crazyjavahacking.astvisualizer.api.model;


import java.util.Collections;
import java.util.Set;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.ToString;


/**
 * Node model. Node model consists of depth, order, leaf flag, treeKind, textualRepresentation, javadoc, position
 * within source code and properties. Every node model could have multiple properties.
 *
 * @see NodeModelProperty
 *
 * @author Martin Skurla (crazyjavahacking@gmail.com)
 */
@AllArgsConstructor
@Getter
@ToString
public final class NodeModel {

    //-----------------------------------------------------------------------------------------------------------------
    // Members.
    //-----------------------------------------------------------------------------------------------------------------
    private final int depth;
    private final int order;

    private final boolean leaf;

    private final String treeKind;
    private final String textualRepresentation;
    private final String javadoc;

    private final PositionWithinSourceCode positionWithinSourceCode;

    private final Set<NodeModelProperty> properties;


    //-----------------------------------------------------------------------------------------------------------------
    // Public Methods.
    //-----------------------------------------------------------------------------------------------------------------
    /**
     * Returns <b>unmodifiable</b> set of properties.
     *
     * @return unmodifiable set of properties
     */
    public Set<NodeModelProperty> getProperties() {
        return Collections.unmodifiableSet(properties);
    }
}
